Installation
============
The most recent release can be installed from
`PyPI <https://pypi.org/project/zenodo_client>`_ with:

.. code-block:: shell

    $ pip install zenodo_client

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/zenodo-client.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/cthoyt/zenodo-client.git
    $ cd zenodo-client
    $ pip install -e .
